- node
node
- X
array-like of shape [n_inputs], [series], timesteps, input_dim), optional
Input sequences dataset. If None, the method will try to fit
the parameters of the Node using the precomputed values returned
by previous call of :py:meth:partial_fit.
- Y
array-like of shape ([series], timesteps, output_dim), optional
Teacher signals dataset. If None, the method will try to fit
the parameters of the Node using the precomputed values returned
by previous call of :py:meth: partial_fit, or to fit the Node in
an unsupervised way, if possible.
- warmup
: int, default to 0
Number of timesteps to consider as warmup and
discard at the begining of each timeseries before training.
- stateful
is boolen
- reset
is boolean. Should the node status be reset before fitting.